 
 ​#​ ​**[​ScsLabs​](https://pypi.org/project/ScsLabs/)**​ ~ Alat bantu untuk para Pelajar & Pengembangan 
 ​Skull Cyber Security Labs adalah modul Python untuk pembelajaran yang dapat menjalankan perintah pada program komputer.

 #​ ​[Dokumentasi ScsLabs](https://github.com/SkullCyberSecurity/ScsLabs/)
 
 ​#​ ​Fitur yang tersedia saat ini: 
 ​-​ DNS Loockup (Whois Domain Loockup) ​`whois_domain("example.com")` 
 ​-​ APNIC Lockup (IP Address Loockup) ​`whois_ip("ip")`
